==> angular-webpack-transformer-0.0.1.tgz: package/src/utils/rules.ts <==
import * as webpack from 'webpack';
import { PreloaderHandlerCallback, RuleTestType } from './types';

export const find = (
  ruleType: RuleTestType,
  config: webpack.Configuration
): Array<webpack.RuleSetRule> => {
  if (!config) {
    console.warn(
      `rules.find: webpack config required! find(ruleType: RuleTestType, config: webpack.Configuration)`
    );
    return [];
  }
  if (!config.module?.rules) {
    return [];
  }
  let rules = config.module.rules as Array<webpack.RuleSetRule>;

  return rules.filter((rule) => {
    return (
      'object' == typeof rule &&
      rule?.test?.toString() == new RegExp(ruleType, 'i').toString()
    );
  });
};

export const modifyOrAddLoader = (
  ruleTypes: Array<RuleTestType> = [],
  loaderName: string,
  callback: PreloaderHandlerCallback,
  config: webpack.Configuration
): void => {
  if (!config) {
    console.warn(
      `modifyLoaders: webpack config required! modifyLoaders(ruleType: RuleTestType, loaderName: string, cb: PreloaderHandler, config: webpack.Configuration)`
    );
    return;
  }
  const rules: Array<webpack.RuleSetRule> = [];

  for (let ruleType of ruleTypes) {
    rules.push(...find(ruleType, config));
  }
  if (!rules.length) {
    return;
  }
  for (let ruleTest of rules) {
    for (let rule of ruleTest.rules as Array<webpack.RuleSetRule>) {
      if ('object' == typeof rule && Array.isArray(rule?.use)) {
        const loaders = rule?.use?.filter((use) => {
          return (
            ('string' == typeof use &&
              use
                .trim()
                .toLocaleLowerCase()
                .includes(loaderName.trim().toLocaleLowerCase())) ||
            ('object' == typeof use &&
              use.loader
                ?.trim()
                .toLocaleLowerCase()
                .includes(loaderName.trim().toLocaleLowerCase()))
          );
        });
        if (loaders.length) {
          for (let loader of loaders) {
            let indexOf = rule?.use.indexOf(loader);
            let _loader: webpack.RuleSetUseItem =
              'string' == loader
                ? {
                    loader: 'loaderName',
                    options: {},
                  }
                : loader;

            let result = callback(_loader, rule.use);
            if (result) {
              rule?.use.splice(indexOf, 1, result);
            }
          }
        } else {
          callback(null, rule.use);
        }
      }
    }
  }
};

==> angular-webpack-transformer-1.0.2.tgz: package/src/utils/rules.ts <==
import * as webpack from "webpack";
import { PreloaderHandlerCallback, RuleTestType } from "./types";

export const find = (
  ruleType: RuleTestType,
  config: webpack.Configuration
): Array<webpack.RuleSetRule> => {
  if (!config) {
    console.warn(
      `rules.find: webpack config required! find(ruleType: RuleTestType, config: webpack.Configuration)`
    );
    return [];
  }
  if (!config.module?.rules) {
    return [];
  }
  let rules = config.module.rules as Array<webpack.RuleSetRule>;

  return rules.filter((rule) => {
    return (
      "object" == typeof rule &&
      rule?.test?.toString() == new RegExp(ruleType, "i").toString()
    );
  });
};

export const modifyOrAddLoader = (
  ruleTypes: Array<RuleTestType> = [],
  loaderName: string,
  callback: PreloaderHandlerCallback,
  config: webpack.Configuration
): void => {
  if (!config) {
    console.warn(
      `modifyLoaders: webpack config required! modifyLoaders(ruleType: RuleTestType, loaderName: string, cb: PreloaderHandler, config: webpack.Configuration)`
    );
    return;
  }
  const rules: Array<webpack.RuleSetRule> = [];
  for (let ruleType of ruleTypes) {
    let found = find(ruleType, config);
    if (!found.length) {
      let rule = {
        test: RegExp(ruleType, "i"),
        rules: [
          {
            use: [],
          },
        ],
      };
      config.module?.rules?.push(rule);
      rules.push(rule);
    } else {
      rules.push(...found);
    }
  }

  for (let ruleTest of rules) {
    if (!ruleTest.rules) {
      ruleTest.rules = [];
    }
    for (let rule of ruleTest.rules as Array<webpack.RuleSetRule>) {
      if ("object" == typeof rule && Array.isArray(rule?.use)) {
        const loaders = rule?.use?.filter((use) => {
          return (
            ("string" == typeof use &&
              use
                .trim()
                .toLocaleLowerCase()
                .includes(loaderName.trim().toLocaleLowerCase())) ||
            ("object" == typeof use &&
              use.loader
                ?.trim()
                .toLocaleLowerCase()
                .includes(loaderName.trim().toLocaleLowerCase()))
          );
        });
        if (loaders.length) {
          for (let loader of loaders) {
            let indexOf = rule?.use.indexOf(loader);
            let _loader: webpack.RuleSetUseItem =
              "string" == loader
                ? {
                    loader: "loaderName",
                    options: {},
                  }
                : loader;

            let result = callback(_loader, rule.use);
            if (result) {
              rule?.use.splice(indexOf, 1, result);
            }
          }
        } else {
          callback(null, rule.use);
        }
      }
    }
  }
};
